local ACR = LibStub("AceConfigRegistry-3.0")
local ACD = LibStub("AceConfigDialog-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("Deadpool", true)

function loadDeadpoolOptions()
	local DeadpoolOptions = {
		type = "group",
		name = format("%s |cffADFF2Fv%s|r", "Dead Pool", GetAddOnMetadata("Deadpool", "Version")),
		args = {
			general = {
				type = "group", order = 1,
				name = L["GENERAL_SECTION"],
				inline = true,
				args = {
					enableSound = {
						type = "toggle", order = 1,
						name = L["ENABLE_SOUND"],
						desc = L["ENABLE_SOUND_DESC"],
						set = function(info, val) 
							DeadpoolOptionsData["DeadpoolSoundsDisabled"] = not val
						end,
						get = function(info)
							local enabled = true
							if DeadpoolOptionsData["DeadpoolSoundsDisabled"] ~= nil then
								enabled = not DeadpoolOptionsData["DeadpoolSoundsDisabled"]
							end
							return enabled
						end
					},
					enableDeathAnnounce = {
						type = "toggle", order = 2,
						name = L["ENABLE_DEATH_ANNOUNCE"],
						desc = L["ENABLE_DEATH_ANNOUNCE_DESC"],
						set = function(info, val) 
							DeadpoolOptionsData["DeadpoolDeathAnnounceDisabled"] = not val
						end,
						get = function(info)
							local enabled = true
							if DeadpoolOptionsData["DeadpoolDeathAnnounceDisabled"] ~= nil then
								enabled = not DeadpoolOptionsData["DeadpoolDeathAnnounceDisabled"]
							end
							return enabled
						end
					},
					enableAchievementAnnounce = {
						type = "toggle", order = 3,
						name = L["ENABLE_ACHIEVEMENT_ANNOUNCE"],
						desc = L["ENABLE_ACHIEVEMENT_ANNOUNCE_DESC"],
						set = function(info, val) 
							DeadpoolOptionsData["DeadpoolAchievementAnnounceDisabled"] = not val
						end,
						get = function(info)
							local enabled = true
							if DeadpoolOptionsData["DeadpoolAchievementAnnounceDisabled"] ~= nil then
								enabled = not DeadpoolOptionsData["DeadpoolAchievementAnnounceDisabled"]
							end
							return enabled
						end
					},
					enableMiniMapButton = {
						type = "toggle", order = 4,
						name = L["ENABLE_MINIMAPBUTTON"],
						desc = L["ENABLE_MINIMAPBUTTON_DESC"],
						set = function(info, val)
							DeadpoolMIcon.minimapIcon.hide = not DeadpoolMIcon.minimapIcon.hide
							local libDBIcon = LibStub("LibDBIcon-1.0")
							if DeadpoolMIcon.minimapIcon.hide then
								libDBIcon:Hide("Deadpool")
							else
								libDBIcon:Show("Deadpool")
							end
						end,
						get = function(info)
							return not DeadpoolMIcon.minimapIcon.hide
						end
					},
					enableTuto = {
						type = "toggle", order = 5,
						name = L["ENABLE_TUTO"],
						desc = L["ENABLE_TUTO_DESC"],
						set = function(info, val) 
							DeadpoolOptionsData["TutoDisabled"] = not val
							DeadpoolTuto = {}
						end,
						get = function(info)
							local enabled = true
							if DeadpoolOptionsData["TutoDisabled"] ~= nil then
								enabled = not DeadpoolOptionsData["TutoDisabled"]
							end
							return enabled
						end
					}
				},
			},
			window = {
				type = "group", order = 2,
				name = L["WINDOW_SECTION"],
				inline = true,
				args = {
					hideInCombat = {
						type = "toggle", order = 1,
						name = L["HIDE_IN_COMBAT"],
						desc = L["HIDE_IN_COMBAT_DESC"],
						set = function(info, val) 
							DeadpoolOptionsData["DeadpoolHideInCombat"] = val
						end,
						get = function(info)
							return DeadpoolOptionsData["DeadpoolHideInCombat"]
						end
					},
					alpha = {
						type = "range", order = 2,
						width = "full", descStyle = "",
						name = L["DEADPOOLFRAME_ALPHA"],
						get = function(i)
							return DeadpoolOptionsData["DeadpoolFrameAlpha"]
						end,
						set = function(i, v)
							DeadpoolOptionsData["DeadpoolFrameAlpha"] = v
							DeadpoolFrame:SetAlpha(v)
						end,
						min = 0.2,
						max = 1.0,
						step = 0.05,
					},
					lineHeight = {
						type = "range", order = 3,
						width = "full", descStyle = "",
						name = L["DEADPOOLFRAME_LINEHEIGHT"],
						get = function(i)
							return DeadpoolOptionsData["DeadpoolLigneHeight"]
						end,
						set = function(i, v)
							local newMinHeight = 151 + v
							DeadpoolFrame:SetMinResize(0, newMinHeight)
							DeadpoolOptionsData["DeadpoolLigneHeight"] = v
							if DeadpoolFrame:GetHeight() < newMinHeight then
								DeadpoolFrame:SetHeight(newMinHeight)
								DeadpoolOptionsData["DeadpoolHeight"] = newMinHeight
							end
							generateDeadpoolTable()
						end,
						min = 20,
						max = 30,
						step = 2,
					}
				}
			}
		},
	}

	ACR:RegisterOptionsTable("Dead Pool", DeadpoolOptions)
	ACD:AddToBlizOptions("Dead Pool", "Dead Pool")
	ACD:SetDefaultSize("Dead Pool", 420, 340)
end
